==> paycenter-client-3.3.73.2-20220316.064740-2-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/ningbobank/charge/NbcbChargeRequestDto.java <==
package cn.com.duiba.paycenter.dto.payment.charge.ningbobank.charge;


import cn.com.duiba.paycenter.dto.payment.charge.BaseChargeRequest;

/**
 * 预支付请求实体类
 *
 * @author fja
 * @date 2022-03-12
 */
public class NbcbChargeRequestDto extends BaseChargeRequest {
    /**
     * 兑吧应用Id
     */
    private Long duibaAppId;

    /**
     * 开发者用户Id
     */
    private String partnerUserId;

    /**
     * 主订单
     */
    private String bizOrderNo;

    /**
     * 订单描述
     */
    private String orderDesc;

    private String notifyUrl;

    /**
     * 进入支付页后跳转回商户的地址，不传的话，可能无法返回。
     */
    private String payFrontUrl;

    /**
     * 进入支付页后跳转回商户的地址，不传的话，可能无法返回。
     */
    private String paySuccessUrl;

    /**
     * 从支付页、支付完成或失败后返回商户时的页面标题名称
     */
    private String payFrontTitle;

    /**
     * ip
     */
    private String ip;




    public Long getDuibaAppId() {
        return duibaAppId;
    }

    public void setDuibaAppId(Long duibaAppId) {
        this.duibaAppId = duibaAppId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    @Override
    public String getBizOrderNo() {
        return bizOrderNo;
    }

    @Override
    public void setBizOrderNo(String bizOrderNo) {
        this.bizOrderNo = bizOrderNo;
    }

    public String getOrderDesc() {
        return orderDesc;
    }

    public void setOrderDesc(String orderDesc) {
        this.orderDesc = orderDesc;
    }

    public String getNotifyUrl() {
        return notifyUrl;
    }

    public void setNotifyUrl(String notifyUrl) {
        this.notifyUrl = notifyUrl;
    }

    public String getPayFrontUrl() {
        return payFrontUrl;
    }

    public void setPayFrontUrl(String payFrontUrl) {
        this.payFrontUrl = payFrontUrl;
    }

    public String getPayFrontTitle() {
        return payFrontTitle;
    }

    public void setPayFrontTitle(String payFrontTitle) {
        this.payFrontTitle = payFrontTitle;
    }

    public String getPaySuccessUrl() {
        return paySuccessUrl;
    }

    public void setPaySuccessUrl(String paySuccessUrl) {
        this.paySuccessUrl = paySuccessUrl;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }
}

==> paycenter-client-3.4.18-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/ningbobank/charge/NbcbChargeRequestDto.java <==
package cn.com.duiba.paycenter.dto.payment.charge.ningbobank.charge;


import cn.com.duiba.paycenter.dto.payment.charge.BaseChargeRequest;

import java.util.Date;

/**
 * 预支付请求实体类
 *
 * @author fja
 * @date 2022-03-12
 */
public class NbcbChargeRequestDto extends BaseChargeRequest {
    /**
     * 兑吧应用Id
     */
    private Long duibaAppId;

    /**
     * 开发者用户Id
     */
    private String partnerUserId;

    /**
     * 订单描述
     */
    private String orderDesc;

    /**
     * 通知地址
     */
    private String notifyUrl;

    /**
     * 进入支付页后跳转回商户的地址，不传的话，可能无法返回。
     */
    private String payFrontUrl;

    /**
     * 进入支付页后跳转回商户的地址，不传的话，可能无法返回。
     */
    private String paySuccessUrl;

    /**
     * 从支付页、支付完成或失败后返回商户时的页面标题名称
     */
    private String payFrontTitle;

    /**
     * ip
     */
    private String ip;

    /**
     * 主订单生成日期
     */
    private Date merDate;


    public Long getDuibaAppId() {
        return duibaAppId;
    }

    public void setDuibaAppId(Long duibaAppId) {
        this.duibaAppId = duibaAppId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public String getOrderDesc() {
        return orderDesc;
    }

    public void setOrderDesc(String orderDesc) {
        this.orderDesc = orderDesc;
    }

    public String getNotifyUrl() {
        return notifyUrl;
    }

    public void setNotifyUrl(String notifyUrl) {
        this.notifyUrl = notifyUrl;
    }

    public String getPayFrontUrl() {
        return payFrontUrl;
    }

    public void setPayFrontUrl(String payFrontUrl) {
        this.payFrontUrl = payFrontUrl;
    }

    public String getPayFrontTitle() {
        return payFrontTitle;
    }

    public void setPayFrontTitle(String payFrontTitle) {
        this.payFrontTitle = payFrontTitle;
    }

    public String getPaySuccessUrl() {
        return paySuccessUrl;
    }

    public void setPaySuccessUrl(String paySuccessUrl) {
        this.paySuccessUrl = paySuccessUrl;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }


    public Date getMerDate() {
        return merDate;
    }

    public void setMerDate(Date merDate) {
        this.merDate = merDate;
    }
}
